mysql.stmt.bind_out.Out_Set

Package mysql :: Package stmt :: Module bind_out :: Class Out_Set |
[hide private]
[frames] | no frames]

# Class Out_Set

     object --+
              |
    Output_Bind --+
                  |
    Base_Out_String --+
                      |
                     Out_Set

SET output binding.

The constructor takes 3 arguments:

- `who`: The object in which to set the value.
- `what`: The name of the parameter in the object to set.
- `max_size`: The maximum size of the string. Attempting to load a value that is larger than this value will raise mysql.exceptions.Data_Truncated in the call to `fetch` and the data will be truncated to this length.

The resulting value will be a `sets.Set` instance.

Instance Methods | [hide private]
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `Base_Out_String`: `__init__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e8d8>`

Instance Variables | [hide private]
Inherited from `Output_Bind`: `error`, `is_null`, `length` Inherited from `Output_Bind` (private): `_buffer`, `_buffer_length`, `_buffer_type`, `_is_unsigned`, `_what`, `_who`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: Base_Out_String.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e8d8>